@@ -1,4 +1,5 @@
 from cmu_graphics.shape_logic import TRANSLATED_KEY_NAMES
+from cmu_graphics import shape_logic
 
 EPSILON = 10e-7
 def almostEqual(x, y, epsilon=EPSILON):
@@ -207,6 +208,10 @@ def translateKeyName(keyName, originalLanguage):
     if originalLanguage not in TRANSLATED_KEY_NAMES: return keyName
     return KeyName(TRANSLATED_KEY_NAMES[originalLanguage].get(keyName, keyName))
 
+def cleanAndClose():
+    shape_logic.cleanSoundProcesses()
+    os._exit(0)
+
 # Based on Lukas Peraza's pygame framework
 # https://github.com/LBPeraza/Pygame-Asteroids
 class App(object):
@@ -289,7 +294,7 @@ class App(object):
             'left': 0,
             'width': self.width,
             'height': self.height,
-            'fill': self.background,
+            'fill': self.background or 'white',
         })
         shape.draw(ctx)
 
@@ -340,9 +345,9 @@ class App(object):
         self.width = self.right = width
         self.height = self.bottom = height
         self._allKeysDown = set()
-        self.background = 'white'
+        self.background = None
 
-        self.stepsPerSecond = 30
+        self._stepsPerSecond = 30
 
         self._tlg = Group()
         sli.setTopLevelGroup(self._tlg)
@@ -368,6 +373,13 @@ class App(object):
         raise Exception('App.stopped is readonly')
     stopped = property(get_stopped, set_stopped)
 
+    def getStepsPerSecond(self):
+        return self._stepsPerSecond
+    def setStepsPerSecond(self, value):
+        shape_logic.checkNumber(sli.t('app'), 'stepsPerSecond', value, False)
+        self._stepsPerSecond = value
+    stepsPerSecond = property(getStepsPerSecond, setStepsPerSecond)
+
     def getBackground(self):
         return sli.slGetAppProperty('background')
     def setBackground(self, value):
@@ -470,7 +482,7 @@ class App(object):
                 pygame.time.wait(1)
 
         pygame.quit()
-        os._exit(0)
+        cleanAndClose()
 
 class AppWrapper(object):
     attrs = ['background', 'group', 'stepsPerSecond', 'paused', 'stop',
@@ -526,13 +538,13 @@ def run():
     try:
         app._app.run()
     except KeyboardInterrupt:
-        os._exit(0)
+        cleanAndClose()
 
 from code import InteractiveConsole
 class CSAcademyConsole(InteractiveConsole):
     def __init__(self):
         self.__class__.__name__ = "CS Academy Console"
-        __main__.__dict__['exit'] = lambda: os._exit(0)
+        __main__.__dict__['exit'] = lambda: cleanAndClose()
         super().__init__(locals=__main__.__dict__, filename = '<%s>' % self.__class__.__name__)
 
     # Override the default error handling functions to avoid using our own
@@ -566,10 +578,10 @@ class CSAcademyConsole(InteractiveConsole):
         finally:
             last_tb = ei = None
 
-    # Override interact so we can os._exit on EOF
+    # Override interact so we can exit on EOF
     def interact(self):
         super().interact()
-        os._exit(0)
+        cleanAndClose()
 
 import os
 import sys
@@ -692,28 +704,28 @@ def check_for_exit_without_run():
     # The app's top level group is created even if the user creates no
     # shapes on their own
     if SHAPES_CREATED > 1 and not MAINLOOP_RUN:
-        print("""                                           
-                         (                                              
-                    (    (                                              
-                    ((  (*(                                             
-                    (*( (*/                                             
-                    (**.***,                                            
-                    (***************((((((((((((((((                    
-                    (********************************                   
-                    (*******************************(                   
-                    (*******************************(                   
-                    (*******************************(                   
-                    /*******************************(                   
-                    (/******************(((((((     ((                   
-                (*****(****************,                                
-                /**********(************(                                 
-            ((***************(*********                                  
-                (*****(/*********(*****(                                  
-                    (**********/(/***(*/                                   
-                    (****************(                                  
-                        (/***********(                                    
-                            (*******(                                      
-                            (**(                                                                                                          
+        print("""
+                         (
+                    (    (
+                    ((  (*(
+                    (*( (*/
+                    (**.***,
+                    (***************((((((((((((((((
+                    (********************************
+                    (*******************************(
+                    (*******************************(
+                    (*******************************(
+                    /*******************************(
+                    (/******************(((((((     ((
+                (*****(****************,
+                /**********(************(
+            ((***************(*********
+                (*****(/*********(*****(
+                    (**********/(/***(*/
+                    (****************(
+                        (/***********(
+                            (*******(
+                            (**(
 """)
         print(" ** To run your animation, add cmu_graphics.run() to the bottom of your file **\n")
 
